diff --git a/Etage.cabal b/Etage.cabal
--- a/Etage.cabal
+++ b/Etage.cabal
@@ -1,5 +1,5 @@
 Name:                Etage
-Version:             0.1.2
+Version:             0.1.3
 Synopsis:            A general data-flow framework
 Description:         A general data-flow framework featuring nondeterminism, laziness and neurological pseudo-terminology. It can be
                      used for example for data-flow computations or event propagation networks. It tries hard to aide type checking and to
diff --git a/lib/Control/Etage/Externals.hs b/lib/Control/Etage/Externals.hs
--- a/lib/Control/Etage/Externals.hs
+++ b/lib/Control/Etage/Externals.hs
@@ -56,7 +56,8 @@
   prepareEnvironment,
   getCurrentImpulseTime,
   impulseEq,
-  impulseCompare
+  impulseCompare,
+  bracketOnErrorUnmasked
 ) where
 
 import Prelude hiding (catch)
@@ -428,3 +429,12 @@
 -}
 impulseCompare :: (Impulse i, Impulse j) => i -> j -> Ordering
 impulseCompare a b = (impulseTime a, impulseValue a) `compare` (impulseTime b, impulseValue b)
+
+{-|
+Similar to 'bracketOnError' only that the first computation does not have asynchronous exceptions masked.
+-}
+bracketOnErrorUnmasked :: IO a -> (a -> IO b) -> (a -> IO c) -> IO c
+bracketOnErrorUnmasked before after thing =
+  mask $ \restore -> do
+    a <- restore before
+    restore (thing a) `onException` after a
diff --git a/lib/Control/Etage/Function.hs b/lib/Control/Etage/Function.hs
--- a/lib/Control/Etage/Function.hs
+++ b/lib/Control/Etage/Function.hs
@@ -1,4 +1,4 @@
-{-# LANGUAGE TypeFamilies, MultiParamTypeClasses, GADTs, FlexibleInstances, ScopedTypeVariables, DeriveDataTypeable, TypeSynonymInstances, NamedFieldPuns, BangPatterns #-}
+{-# LANGUAGE TypeFamilies, MultiParamTypeClasses, GADTs, FlexibleInstances, ScopedTypeVariables, DeriveDataTypeable, TypeSynonymInstances, NamedFieldPuns #-}
 
 {-|
 This module defines a 'Neuron' which applies a given function to received 'Impulse's. As Haskell is a lazy language this does
diff --git a/lib/Control/Etage/Incubator.hs b/lib/Control/Etage/Incubator.hs
--- a/lib/Control/Etage/Incubator.hs
+++ b/lib/Control/Etage/Incubator.hs
@@ -54,7 +54,7 @@
   -- > grow options = do
   -- >   ...
   -- >   nerve <- growNerve
   -- >   bracketOnError (attach defaultOptions nerve) detachAndWait $ \neuron -> do
   -- >     ...
   -- >     return $ YourNeuron ... neuron nerve
   -- >
@@ -62,7 +62,7 @@
   -- >   detachAndWait neuron
   -- >   ...
   --
   -- We use 'bracketOnError' there to be sure that 'Neuron' is properly 'dissolve'd even if there is an exception later on in
   -- 'grow'ing the parent 'Neuron'. And we use 'detachAndWait' so that we give time for child 'Neuron' to 'dissolve' properly.
   -- Which 'Neuron' you want is in this case inferred from the type of the 'Nerve' you defined.
   growNerve,
@@ -117,7 +117,7 @@
           eval ns cs ats (NeuronOperation optionsSetter :>>= is) = do
             nerve <- liftIO growNerve
             let c = getFromChan nerve
-            bracketOnError (attach optionsSetter nerve) detachAndWait $ \n -> interpret (n:ns) (c ++ cs) ats . is $ nerve
+            bracketOnErrorUnmasked (attach optionsSetter nerve) detachAndWait $ \n -> interpret (n:ns) (c ++ cs) ats . is $ nerve
           eval ns cs ats (AttachOperation from for :>>= is) = do
             let c = head . getFromChan $ from -- we know there exists from chan as type checking assures that (from is conductive)
             (from', ats') <- if c `notElem` ats
@@ -54,7 +54,7 @@
   -- >   ...
   -- >   nerve <- growNerve
-  -- >   bracketOnError (attach defaultOptions nerve) detachAndWait $ \neuron -> do
+  -- >   bracketOnErrorUnmasked (attach defaultOptions nerve) detachAndWait $ \neuron -> do
   -- >     ...
   -- >     return $ YourNeuron ... neuron nerve
@@ -62,7 +62,7 @@
   -- >   ...
   --
-  -- We use 'bracketOnError' there to be sure that 'Neuron' is properly 'dissolve'd even if there is an exception later on in
+  -- We use 'bracketOnErrorUnmasked' there to be sure that 'Neuron' is properly 'dissolve'd even if there is an exception later on in
   -- 'grow'ing the parent 'Neuron'. And we use 'detachAndWait' so that we give time for child 'Neuron' to 'dissolve' properly.
   -- Which 'Neuron' you want is in this case inferred from the type of the 'Nerve' you defined.
